Class IdentifierUtility
java.lang.Object
org.refcodes.internal.IdentifierUtility
The
IdentifierUtility utility class addresses normalizing
identifiers such as keys or parameter names. The normalized variant then can
be transformed into a valid system property name or environment variable name
("valid" as of the according conventions).-
Field Summary
Fields -
Method Summary
Modifier and TypeMethodDescriptionstatic StringtoNormalized(String aText, char aSeparator) Normalizes the provided text by removing all non-alphanumeric and non-numeric prefixed and suffixed characters, adding a separator whenever lower case characters are followed by upper case characters and by converting multiple succeeding separators to a single separator and by converting all upper case characters to lower case.
-
Field Details
-
REGEX_SPECIAL_CHARS
public static final char[] REGEX_SPECIAL_CHARS
-
-
Method Details
-
toNormalized
Normalizes the provided text by removing all non-alphanumeric and non-numeric prefixed and suffixed characters, adding a separator whenever lower case characters are followed by upper case characters and by converting multiple succeeding separators to a single separator and by converting all upper case characters to lower case.
-